@@ -1,6 +1,6 @@
 # tifffile/numcodecs.py
 
-# Copyright (c) 2021, Christoph Gohlke
+# Copyright (c) 2021-2022, Christoph Gohlke
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -31,9 +31,7 @@
 
 """TIFF codec for numcodecs based on tifffile."""
 
-__version__ = '2021.4.x'
-
-__all__ = ('register_codec', 'Tiff')
+__all__ = ['register_codec', 'Tiff']
 
 from io import BytesIO
 
@@ -118,6 +116,7 @@ class Tiff(Codec):
                     subsampling=self.subsampling,
                     metadata=self.metadata,
                     extratags=self.extratags,
+                    maxworkers=self.maxworkers,
                 )
             result = fh.getvalue()
         return result
